.. _example_usage:

Example Usage
=============

This example is a reproduction of Figure 1 from http://doi.org/10.1098/rspa.2007.1900 :

The original figure:

.. image:: https://royalsocietypublishing.org/cms/asset/efa57e07-5384-4503-8b2b-ccbe632ffe87/3251fig1.jpg
  :width: 640

Code to reproduce the above figure as close as possible:

.. literalinclude:: ../scripts/example-usage.py
   :language: python
   :emphasize-lines: 13,14,16,34,35
   :linenos:

Reproduced figure:

.. image:: ../_static/recreating-forrester-2007.png
  :width: 640
